==> zio-aws-codestarconnections_2.13-5.17.151.2-sources.jar: zio/aws/codestarconnections/model/package.scala <==
package zio.aws.codestarconnections
import zio.prelude.Subtype
import zio.aws.codestarconnections.model.primitives.{
  TagKey,
  SubnetId,
  SecurityGroupId
}
import zio.aws.codestarconnections.model.primitives.ConnectionArn.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AccountId extends Subtype[String]
    type AccountId = zio.aws.codestarconnections.model.primitives.AccountId.Type
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.codestarconnections.model.primitives.AmazonResourceName.Type
    object ConnectionArn extends Subtype[String]
    type ConnectionArn =
      zio.aws.codestarconnections.model.primitives.ConnectionArn.Type
    object ConnectionName extends Subtype[String]
    type ConnectionName =
      zio.aws.codestarconnections.model.primitives.ConnectionName.Type
    object HostArn extends Subtype[String]
    type HostArn = zio.aws.codestarconnections.model.primitives.HostArn.Type
    object HostName extends Subtype[String]
    type HostName = zio.aws.codestarconnections.model.primitives.HostName.Type
    object HostStatus extends Subtype[String]
    type HostStatus =
      zio.aws.codestarconnections.model.primitives.HostStatus.Type
    object HostStatusMessage extends Subtype[String]
    type HostStatusMessage =
      zio.aws.codestarconnections.model.primitives.HostStatusMessage.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.codestarconnections.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.codestarconnections.model.primitives.NextToken.Type
    object SecurityGroupId extends Subtype[String]
    type SecurityGroupId =
      zio.aws.codestarconnections.model.primitives.SecurityGroupId.Type
    object SubnetId extends Subtype[String]
    type SubnetId = zio.aws.codestarconnections.model.primitives.SubnetId.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.codestarconnections.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.codestarconnections.model.primitives.TagValue.Type
    object TlsCertificate extends Subtype[String]
    type TlsCertificate =
      zio.aws.codestarconnections.model.primitives.TlsCertificate.Type
    object Url extends Subtype[String]
    type Url = zio.aws.codestarconnections.model.primitives.Url.Type
    object VpcId extends Subtype[String]
    type VpcId = zio.aws.codestarconnections.model.primitives.VpcId.Type
  }
  type ConnectionList = List[zio.aws.codestarconnections.model.Connection]
  type HostList = List[zio.aws.codestarconnections.model.Host]
  type SecurityGroupIds = List[SecurityGroupId]
  type SubnetIds = List[SubnetId]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.codestarconnections.model.Tag]
}

==> zio-aws-codestarconnections_3-5.17.295.6-sources.jar: zio/aws/codestarconnections/model/package.scala <==
package zio.aws.codestarconnections
import zio.prelude.Subtype
import zio.aws.codestarconnections.model.primitives.{
  TagKey,
  SubnetId,
  SecurityGroupId
}
import zio.aws.codestarconnections.model.primitives.ConnectionArn.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AccountId extends Subtype[String]
    type AccountId = zio.aws.codestarconnections.model.primitives.AccountId.Type
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.codestarconnections.model.primitives.AmazonResourceName.Type
    object ConnectionArn extends Subtype[String]
    type ConnectionArn =
      zio.aws.codestarconnections.model.primitives.ConnectionArn.Type
    object ConnectionName extends Subtype[String]
    type ConnectionName =
      zio.aws.codestarconnections.model.primitives.ConnectionName.Type
    object HostArn extends Subtype[String]
    type HostArn = zio.aws.codestarconnections.model.primitives.HostArn.Type
    object HostName extends Subtype[String]
    type HostName = zio.aws.codestarconnections.model.primitives.HostName.Type
    object HostStatus extends Subtype[String]
    type HostStatus =
      zio.aws.codestarconnections.model.primitives.HostStatus.Type
    object HostStatusMessage extends Subtype[String]
    type HostStatusMessage =
      zio.aws.codestarconnections.model.primitives.HostStatusMessage.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.codestarconnections.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.codestarconnections.model.primitives.NextToken.Type
    object SecurityGroupId extends Subtype[String]
    type SecurityGroupId =
      zio.aws.codestarconnections.model.primitives.SecurityGroupId.Type
    object SubnetId extends Subtype[String]
    type SubnetId = zio.aws.codestarconnections.model.primitives.SubnetId.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.codestarconnections.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.codestarconnections.model.primitives.TagValue.Type
    object TlsCertificate extends Subtype[String]
    type TlsCertificate =
      zio.aws.codestarconnections.model.primitives.TlsCertificate.Type
    object Url extends Subtype[String]
    type Url = zio.aws.codestarconnections.model.primitives.Url.Type
    object VpcId extends Subtype[String]
    type VpcId = zio.aws.codestarconnections.model.primitives.VpcId.Type
  }
  type ConnectionList = List[zio.aws.codestarconnections.model.Connection]
  type HostList = List[zio.aws.codestarconnections.model.Host]
  type SecurityGroupIds = List[SecurityGroupId]
  type SubnetIds = List[SubnetId]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.codestarconnections.model.Tag]
}
